//
//  VC1.m
//  PallySDKDemo2
//
//

#import "VC1.h"

#define dm      [BLEDeviceManager sharedInstanceWithPatternType:PatternRealTimeWeighOnly]

@interface VC1 ()

@property (nonatomic, retain) IBOutlet UITextView* textView;
@property (nonatomic, retain) IBOutlet UILabel* displayLabel;

@end

@implementation VC1

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        self.title = NSLocalizedString(@"First", @"First");
        self.tabBarItem.image = [UIImage imageNamed:@"first"];
        [dm setRealTimeWeighDelegate:self];
    }
    return self;
}
							
- (void)viewDidLoad
{
    [super viewDidLoad];
    [self initNotify];
    self.edgesForExtendedLayout = UIRectEdgeNone;
	[self.displayLabel setText:@""];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    [self deallocNotify];
}


#pragma mark - BLEDeviceManagerRealTimeWeighDelegate

- (void)deviceManger:(BLEDeviceManager *)deviceManger updatedRealTimeValue_basedata:(float)basedata uuid:(NSString *)uuid
{
    // Clear messageView
    [self updateTextView:@""];
    
    // update RealTimeWeighValue
    float kgValue = [dm displayValueByKG:basedata];
    [self.displayLabel setText:[NSString stringWithFormat:@"%.2f kg", kgValue]];
    
//    float lbValue = [dm displayValueByLB:basedata];
//    [self.displayLabel setText:[NSString stringWithFormat:@"%.1f lb", lbValue]];
}

- (void)deviceManger:(BLEDeviceManager *)deviceManger updatedRealTimeValue_finalValue_basedata:(float)basedata uuid:(NSString *)uuid
{
    // Clear messageView
    [self updateTextView:@""];
    
    // update RealTimeWeighValue
    float kgValue = [dm displayValueByKG:basedata];
    [self.displayLabel setText:[NSString stringWithFormat:@"%.2f kg", kgValue]];
    
//    float lbValue = [dm displayValueByLB:basedata];
//    [self.displayLabel setText:[NSString stringWithFormat:@"%.1f lb", lbValue]];
    
    // Option, if not need, just delete it.
    [[self.displayLabel layer] removeAllAnimations];
    [UIView beginAnimations:@"finalValue" context:nil];
    [UIView setAnimationRepeatCount:3.0];
    [UIView setAnimationDuration:1.0];
    [UIView setAnimationDelay:0.];
    [UIView setAnimationDelegate:self];
    [UIView setAnimationDidStopSelector:@selector(actionStopped)];
    [self.displayLabel setAlpha:0.0];
    [UIView commitAnimations];
}

- (void)actionStopped
{
    [self.displayLabel setAlpha:1.0];
}

#pragma mark - IBActions

- (IBAction)btnScanPressed:(id)sender
{
    [dm scanNewDevice:5];
    [dm disconnectDevice];
    [NSTimer scheduledTimerWithTimeInterval:5. target:self selector:@selector(connectionTimer:) userInfo:nil repeats:NO];
}

- (IBAction)btnDisconnectPressed:(id)sender
{
    [dm disconnectDevice];
}

-(void)connectionTimer:(NSTimer *)timer
{
    if(dm.peripherals.count > 0) {
        NSLog(@"dm.peripherals.count=%d", (int)(dm.peripherals.count));
        [dm connectPeripheral:[dm.peripherals objectAtIndex:0]];
    }
}


#pragma mark - notify

- (void)initNotify
{
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(updateUI_eventNotice:) name:@"AceBLEMgrEventNotice" object:nil];
    // Action on app life cycle
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(doWhenDidEnterBackground:) name:UIApplicationDidEnterBackgroundNotification object:nil];
}

- (void)deallocNotify
{
    [[NSNotificationCenter defaultCenter] removeObserver:self name:@"AceBLEMgrEventNotice" object:nil];
    // Action on app life cycle
    [[NSNotificationCenter defaultCenter] removeObserver:self name:UIApplicationDidEnterBackgroundNotification object:nil];
}

#pragma mark -

- (void)updateUI_eventNotice:(NSNotification*)notify
{
    int eventId = [(NSNumber*)[notify.userInfo objectForKey:@"AceBLEMgrEventID"] intValue];
    switch (eventId) {
        case EventDeviceUnsupported:
            [self updateTextView:@"Your device doesn't support Bluetooth Low Energy."];
            break;
        case EventNoBLEConnection:
            [self updateTextView:@"Please connect your scale."];
            break;
        case EventBLEDeviceFounded:
            [self updateTextView:@"Device founded."];
            break;
        case EventNoBLEDeviceFound:
            [self updateTextView:@"Cannot find any scale. Please make sure your scale is powered. Note that the scale cannot connect to more than one iOS device at the same time."];
            break;
        case EventBLEConnectted:
            [self updateTextView:@"A BLE deivce connectted."];
            break;
        case EventBLEDisconnectted:
            [self updateTextView:@"A BLE deivce disconnectted."];
            break;
        case EventBLEDiscoverFinished:
            [self updateTextView:@"A BLE deivce services discover finished. \n\(if your app need to weigh repeatedly within onec connect,your app should tips user to pair (by press the pair button behind the scale) with iOS.)"];
            break;
        default:
            break;
    }
}

// This is a option, if your app not need to disconect in backgorond, just delete it.
- (void)doWhenDidEnterBackground:(NSNotification*)notify
{
    printf("Disconnect BLE Link.\n");
    [dm weightScale_turnOn:NO];
    [dm disconnectDevice];
}


#pragma mark -

- (void)updateTextView:(NSString*)msg
{
    self.textView.text = msg;
}


@end
